@@ -3,7 +3,7 @@ context("wdpa_fetch")
 test_that("country name", {
   skip_on_cran()
   skip_if_not(pingr::is_online())
-  x <- suppressWarnings(wdpa_fetch("Liechtenstein", wait = TRUE))
+  x <- suppressWarnings(wdpa_fetch("Liechtenstein", force = TRUE, wait = TRUE))
   expect_is(x, "sf")
   expect_true(all(x$ISO3 == "LIE"))
 })
@@ -11,7 +11,7 @@ test_that("country name", {
 test_that("ISO3", {
   skip_on_cran()
   skip_if_not(pingr::is_online())
-  x <- suppressWarnings(wdpa_fetch("LIE", wait = TRUE))
+  x <- suppressWarnings(wdpa_fetch("LIE", force = TRUE, wait = TRUE))
   expect_is(x, "sf")
   expect_true(all(x$ISO3 == "LIE"))
 })
